@@ -23,12 +23,14 @@ import time
 import subprocess
 
 import utils
+import config
 
 
 class Remote(object):
 
     def __init__(self):
         self._verbose = True
+        self._ssh_master = None
 
     def __del__(self):
         if self._ssh_master is not None and self._ssh_master.poll() is None:
@@ -38,7 +40,6 @@ class Remote(object):
         parts = utils.parse_url(url)
         (self._user, self._host, self._port) = (parts['user'] or 'dotcloud', parts['host'], parts['port'] or '22')
         self._url = url
-        self._ssh_master = None
         self._ssh_sock = '/tmp/dotcloud-{0}.sock'.format(time.time())
         self._ssh_options = (
                 'ssh',
@@ -60,8 +61,8 @@ class Remote(object):
         utils.die('Error: "{0}" failed to be executed. Please make sure it is properly installed.'.format(progname))
 
     def warning_ssh(self):
-        utils.warning('Warning: Please make sure that your SSH key is configured correctly:')
-        utils.warning('http://docs.dotcloud.com/static/tutorials/firststeps/#create-and-setup-your-account')
+        utils.warning('Warning: The SSH connection failed')
+        utils.warning('Please try again. If the problem persists, send an email to support@dotcloud.com.')
         utils.warning('Also please check that your are allowed to make an SSH connection to a custom port.')
 
     def _spawn_ssh_master(self):
@@ -70,6 +71,7 @@ class Remote(object):
         try:
             self._ssh_master = subprocess.Popen(
                     self._ssh_options + (
+                        '-i', config.CONFIG_KEY,
                         '-p', self._port,
                         '-l', self._user,
                         '-S', self._ssh_sock,
@@ -116,6 +118,23 @@ class Remote(object):
         )
         return subprocess.call(scp, close_fds=True)
 
+    def key(self, data):
+        with open(config.CONFIG_KEY, 'w') as f:
+            f.write(data)
+            os.fchmod(f.fileno(), 0600)
+
+    def sftp(self):
+        self._spawn_ssh_master()
+        sftp = (
+                'sftp',
+                '-o', 'Port={0}'.format(self._port),
+                '-o', 'UserKnownHostsFile=/dev/null',
+                '-o', 'StrictHostKeyChecking=no',
+                '-o', 'ControlPath={0}'.format(self._ssh_sock),
+                '{user}@{host}'.format(user=self._user, host=self._host)
+                )
+        return subprocess.call(sftp, close_fds=True)
+
     def push(self, src, dest='.'):
         self.info('# push {0} {1}'.format(src, dest))
         return self._scp(src, '{user}@{host}:{dest}'.format(user=self._user, host=self._host, dest=dest))
